Changelog
=========

Changes for the upcoming release can be found in the `"changelog.d" directory <https://github.com/python-mario/mario/tree/master/changelog.d>`_ in our repository.

..
   Do *NOT* add changelog entries here!

   This changelog is managed by towncrier and is compiled at release time.

   See https://www.python-mario.readthedocs.org/en/latest/contributing.html#changelog for details.

.. towncrier release notes start

0.0.143 (2019-07-30)
--------------------


No significant changes.


----


0.1.0 (2019-07-15)
------------------

Changes
^^^^^^^

- First release on PyPI.

---
